@@ -626,7 +626,7 @@ func TestEmbeddedStruct(t *testing.T) {
 				type Query {
 					course: Course!
 				}
-				
+
 				type Course {
 					name: String!
 					createdAt: String!
@@ -1494,6 +1494,40 @@ func TestDeprecatedDirective(t *testing.T) {
 	})
 }
 
+func TestSpecifiedByDirective(t *testing.T) {
+	gqltesting.RunTests(t, []*gqltesting.Test{
+		{
+			Schema: graphql.MustParseSchema(`
+			schema {
+				query: Query
+			}
+			type Query {
+			}
+			scalar UUID @specifiedBy(
+				url: "https://tools.ietf.org/html/rfc4122"
+			)
+			`, &struct{}{}),
+			Query: `
+				query {
+					__type(name: "UUID") {
+						name
+						specifiedByURL
+					}
+				}
+			`,
+			Variables: map[string]interface{}{},
+			ExpectedResult: `
+				{
+					"__type": {
+						"name": "UUID",
+						"specifiedByURL": "https://tools.ietf.org/html/rfc4122"
+					}
+				}
+			`,
+		},
+	})
+}
+
 type testBadEnumResolver struct{}
 
 func (r *testBadEnumResolver) Hero() *testBadEnumCharacterResolver {
@@ -1510,6 +1544,24 @@ func (r *testBadEnumCharacterResolver) AppearsIn() []string {
 	return []string{"STAR_TREK"}
 }
 
+func TestUnknownType(t *testing.T) {
+	gqltesting.RunTest(t, &gqltesting.Test{
+		Schema: starwarsSchema,
+		Query: `
+			query TypeInfo {
+				__type(name: "unknown-type") {
+					name
+				}
+			}
+		`,
+		ExpectedResult: `
+			{
+				"__type": null
+			}
+		`,
+	})
+}
+
 func TestEnums(t *testing.T) {
 	gqltesting.RunTests(t, []*gqltesting.Test{
 		// Valid input enum supplied in query text
@@ -1649,6 +1701,23 @@ func TestEnums(t *testing.T) {
 	})
 }
 
+type testDeprecatedArgsResolver struct{}
+
+func (r *testDeprecatedArgsResolver) A(args struct{ B *string }) int32 {
+	return 0
+}
+
+func TestDeprecatedArgs(t *testing.T) {
+	graphql.MustParseSchema(`
+		schema {
+			query: Query
+		}
+		type Query {
+			a(b: String @deprecated): Int!
+		}
+	`, &testDeprecatedArgsResolver{})
+}
+
 func TestInlineFragments(t *testing.T) {
 	gqltesting.RunTests(t, []*gqltesting.Test{
 		{
@@ -1854,11 +1923,11 @@ func TestTypeName(t *testing.T) {
 						}
 					}
 				}
-				
+
 				fragment Droid on Droid {
 					name
 					__typename
-				}			  
+				}
 			`,
 			RawResponse:    true,
 			ExpectedResult: `{"hero":{"__typename":"Droid","name":"R2-D2"}}`,
@@ -2422,7 +2491,8 @@ func TestIntrospection(t *testing.T) {
 									"description": "Marks an element of a GraphQL schema as no longer supported.",
 									"locations": [
 										"FIELD_DEFINITION",
-										"ENUM_VALUE"
+										"ENUM_VALUE",
+										"ARGUMENT_DEFINITION"
 									],
 									"args": [
 										{
@@ -2478,6 +2548,26 @@ func TestIntrospection(t *testing.T) {
 											}
 										}
 									]
+								},
+								{
+									"name": "specifiedBy",
+									"description": "Provides a scalar specification URL for specifying the behavior of custom scalar types.",
+									"locations": [
+										"SCALAR"
+									],
+									"args": [
+										{
+											"name": "url",
+											"description": "The URL should point to a human-readable specification of the data format, serialization, and coercion rules.",
+											"type": {
+												"kind": "NON_NULL",
+												"ofType": {
+													"kind": "SCALAR",
+													"name": "String"
+												}
+											}
+										}
+									]
 								}
 							]
 						}
@@ -3666,6 +3756,106 @@ func TestErrorPropagation(t *testing.T) {
 	})
 }
 
+type assertionResolver struct{}
+
+func (r *assertionResolver) ToHuman() (*struct{ Name string }, bool) {
+	return &struct{ Name string }{Name: "Luke Skywalker"}, true
+}
+
+type assertionQueryResolver struct{}
+
+func (*assertionQueryResolver) Character() *assertionResolver {
+	return &assertionResolver{}
+}
+
+type badAssertionResolver struct{}
+
+func (r *badAssertionResolver) ToHuman(ctx context.Context) (*struct{ Name string }, bool) {
+	return &struct{ Name string }{Name: "Luke Skywalker"}, true
+}
+
+type badAssertionQueryResolver struct{}
+
+func (*badAssertionQueryResolver) Character() *badAssertionResolver {
+	return &badAssertionResolver{}
+}
+
+func TestTypeAssertions(t *testing.T) {
+	assertionSchema := `
+		schema {
+			query: Query
+		}
+
+		type Query {
+			character: Character!
+		}
+
+		type Human {
+			name: String!
+		}
+
+		union Character = Human
+	`
+	query := `
+		query {
+			character {
+				... on Human {
+					name
+				}
+			}
+		}
+	`
+
+	gqltesting.RunTests(t, []*gqltesting.Test{
+		{
+			Schema: graphql.MustParseSchema(assertionSchema, &assertionQueryResolver{}, graphql.UseFieldResolvers()),
+			Query:  query,
+			ExpectedResult: `
+				{
+					"character": {
+						"name": "Luke Skywalker"
+					}
+				}
+			`,
+		},
+	})
+}
+
+func TestPanicTypeAssertionArguments(t *testing.T) {
+	panicMessage := `*graphql_test.badAssertionResolver does not resolve "Character": method "ToHuman" should't have any arguments
+	used by (*graphql_test.badAssertionQueryResolver).Character`
+
+	defer func() {
+		r := recover()
+		if r == nil {
+			t.Fatal("expected schema parse to panic")
+		}
+
+		if r.(error).Error() != panicMessage {
+			t.Logf("got:  %s", r)
+			t.Logf("want: %s", panicMessage)
+			t.Fail()
+		}
+	}()
+
+	schema := `
+		schema {
+			query: Query
+		}
+
+		type Query {
+			character: Character!
+		}
+
+		type Human {
+			name: String!
+		}
+
+		union Character = Human
+	`
+	graphql.MustParseSchema(schema, &badAssertionQueryResolver{}, graphql.UseFieldResolvers())
+}
+
 type ambiguousResolver struct {
 	Name string // ambiguous
 	University
@@ -3700,7 +3890,7 @@ func TestPanicAmbiguity(t *testing.T) {
 			name: String!
 			university: University!
 		}
-		
+
 		type University {
 			name: String!
 		}
@@ -4200,11 +4390,11 @@ func TestQueryVariablesValidation(t *testing.T) {
 			  	required: String!
 			  	optional: String
 			}
-			
+
 			type SearchResults {
 				match: String
 			}
-			
+
 			type Query {
 				search(filter: SearchFilter!): [SearchResults!]!
 			}`, &queryVarResolver{}, graphql.UseFieldResolvers()),
@@ -4225,11 +4415,11 @@ func TestQueryVariablesValidation(t *testing.T) {
 				required: String!
 				optional: String
 			}
-			
+
 			type SearchResults {
 				match: String
 			}
-			
+
 			type Query {
 				search(filter: SearchFilter!): [SearchResults!]!
 			}`, &queryVarResolver{}, graphql.UseFieldResolvers()),
